window.onload = function() {
    TFGraphInit("tfcanvasContainer", "tfcanvas");
    // TFMenuCtrl.initData("LOC" , "TF");
};

var debug;

////////////////////////////////////////////
// AngularJS Module and Controller        //
////////////////////////////////////////////
angular.module('harktool', ["ui.bootstrap"]).controller('tfplotCtrl', function($scope) {
    $scope.path = "";
    $scope.type = "";
    $scope.isRunning = false;

    $scope.filename = localStorage.getItem('tffile');

    function initData(mode, disp) {
        data = {};
        data.tftype = mode; // LOC or SEP
        data.zippath = localStorage.getItem('tffile');
        data.disp = disp; // TF, IFFT

        console.log("disp=", disp);

        if (disp == "TF") //FFT
        {
            $.ajax({
                url: "/genzip2AMPcoord",
                data: data,
                method: "POST"
            }).done(function(path) {
                console.log("@@@@@@@@ genzip2AMPcoord success path=", path);
            }).fail(function(resp) {
                var errorMsg = (resp.responseText) ? resp.responseText : resp.statusText;
                setResult('error', 'Extracting Amplitude information', errorMsg);
            });
            $.ajax({
                url: "/genzip2DBcoord",
                data: data,
                method: "POST"
            }).done(function(path) {
                console.log("@@@@@@@@ genzip2DBcoord success path=", path);
            }).fail(function(resp) {
                var errorMsg = (resp.responseText) ? resp.responseText : resp.statusText;
                setResult('error', 'Extracting Amplitude information in DB', errorMsg);
            });
            $.ajax({
                url: "/genzip2PHASEcoord",
                data: data,
                method: "POST"
            }).done(function(path) {
                console.log("@@@@@@@@ genzip2PHASEcoord success path=", path);
            }).fail(function(resp) {
                var errorMsg = (resp.responseText) ? resp.responseText : resp.statusText;
                setResult('error', 'Extracting Phase information', errorMsg);
            });
        } else //IFFT
        {
            console.log("disp=IFFT");
            $.ajax({
                url: "/genzip2IFFTcoord",
                data: data,
                method: "POST"
            }).done(function(path) {
                console.log("@@@@@@@@ genzip2IFFTcoord success path=", path);
            }).fail(function(resp) {
                var errorMsg = (resp.responseText) ? resp.responseText : resp.statusText;
                setResult('error', 'Extracting Time domain information', errorMsg);
            });
        }
    }

    var tffileinfo = JSON.parse(localStorage.getItem('tffileinfo'));
    var tftypelist = [];
    for (var i = 0; i < tffileinfo.TFInfo.Contents.length; i++) {
        if (tffileinfo.TFInfo.Contents[i] == 'localization') {
            tftypelist.push(["LOC", "Localization"]);
        } else if (tffileinfo.TFInfo.Contents[i] == 'separation') {
            tftypelist.push(["SEP", "Separation"]);
        }
    }

    var integer = { pat: "/[0-9]+/", msg: "Integer required" };
    $scope.tfgraphparams = [{
            id: "tftype",
            name: "TF type",
            value: tftypelist[0][0],
            isList: true,
            list: tftypelist
        }, {
            id: "disp",
            name: "Domain",
            value: "TF",
            isList: true,
            list: [
                ["TF", "Frequency domain", true],
                ["IFFT", "Time domain", false]
            ]
        },
        {
            id: "zaxis",
            name: "Z Axis",
            value: "amp",
            isList: true,
            list: [
                ["amp", "Amplitude", true],
                ["db", "Amplitude in dB", false],
                ["phase", "Phase", false]
            ]
        }, {
            id: "zaxis2",
            name: "Z Axis",
            value: "amp",
            isList: true,
            list: [
                ["amp", "Amplitude", true]
            ],
            isHide: true
        },
    ];

    // set ngchange
    _.each($scope.tfgraphparams, function(dmy, i) { $scope.tfgraphparams[i].ngChange = function() {}; });

    $scope.tfgraphparams[0].ngChange = function() {
        initData($scope.tfgraphparams[0].value, $scope.tfgraphparams[1].value);
        clearResult();
    };

    $scope.tfgraphparams[1].ngChange = function() {
        initData($scope.tfgraphparams[0].value, $scope.tfgraphparams[1].value);
        clearResult();

        if ($scope.tfgraphparams[1].value === "TF") {
            $scope.tfgraphparams[2].isHide = false;
            $scope.tfgraphparams[3].isHide = true;
        } else if ($scope.tfgraphparams[1].value === "IFFT") {
            $scope.tfgraphparams[2].isHide = true;
            $scope.tfgraphparams[3].isHide = false;
        }
    };

    var setResult = function(state, title, resp) {
        if (state == "success") {
            $scope.success = true;
            $scope.error = false;
        } else {
            $scope.success = false;
            $scope.error = true;
            console.log(resp);
            $scope.errorMessageTitle = title;
            $scope.errorMessageCmd = resp.cmd;
            $scope.errorMessage = resp.stderr;
            $scope.$apply();
        }
    };
    var clearResult = function() {
        $scope.success = false;
        $scope.error = false;
    };

    ////////////////////////////////////////////////////
    ///
    /// plot ボタン押下時
    ///
    var prev = "LOC";
    $scope.graphTF = function() {
        $scope.isRunning = true;

        clearResult();

        var data = {};
        _.each($scope.tfgraphparams, function(p) { data[p.id] = p.value; });
        if (data.disp === "IFFT") {
            data.zaxis = data.zaxis2;
        }
        console.log("@@@ graphTF=", data, " z_axis=", data.zaxis);

        var filename = "";
        if (data.disp === "TF") {
            switch (data.zaxis) {
                case "amp":
                    filename = "genzip2AMPcoord.txt";
                    break;
                case "db":
                    filename = "genzip2DBcoord.txt";
                    break;
                case "phase":
                    filename = "genzip2PHASEcoord.txt";
                    break;
                default:
                    filename = "genzip2AMPcoord.txt";
                    break;
            }
        } else {
            filename = "genzip2IFFTcoord.txt";
        }
        console.log(data);

        TFGraphDraw("tfcanvas",
            "/file/" + filename,
            data.zaxis,
            data.disp, //display
            function() { $scope.isRunning = false;
                $scope.$apply(); }
        );
    };

    $scope.tfgraphparams[0].ngChange();
});
